@@ -175,7 +175,7 @@ sub new{
 use SelectSaver;
 sub print{
   my ($this, $out)=@_;
-  my $fdOut=(defined $out)?(new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) or die "cannot open [$out]: $!")):\*STDOUT;
+  my $fdOut=(defined $out)?(new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) or CORE::die "cannot open [$out]: $!")):\*STDOUT;
   print $fdOut "$this->{name} $this->{delta_monoisotopic}"
 }
 
@@ -317,7 +317,7 @@ sub init{
 			 );
   if(@listFiles){
     foreach (@listFiles){
-      die "file [$_] is not readable" unless -r $_;
+      CORE::die "file [$_] is not readable" unless -r $_;
       $twig->parsefile($_) or InSilicoSpectro::Utils::io::croakIt "cannot parse [$_]: $!";
     }
   }else{
